@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from zvdata import IntervalLevel
+from zvt.contract import IntervalLevel
 from zvt.samples import MyMaTrader
 
 
